@@ -2,7 +2,13 @@ from dagster._core.utils import check_dagster_package_version
 
 from .asset_defs import load_assets_from_dbt_manifest, load_assets_from_dbt_project
 from .cli import DbtCliOutput, DbtCliResource, dbt_cli_resource
-from .cloud import DbtCloudOutput, DbtCloudResourceV2, dbt_cloud_resource, dbt_cloud_run_op
+from .cloud import (
+    DbtCloudOutput,
+    DbtCloudResourceV2,
+    dbt_cloud_resource,
+    dbt_cloud_run_op,
+    load_assets_from_dbt_cloud_job,
+)
 from .dbt_resource import DbtResource
 from .errors import (
     DagsterDbtCliFatalRuntimeError,
@@ -10,6 +16,7 @@ from .errors import (
     DagsterDbtCliOutputsNotFoundError,
     DagsterDbtCliRuntimeError,
     DagsterDbtCliUnexpectedOutputError,
+    DagsterDbtCloudJobInvariantViolationError,
     DagsterDbtError,
     DagsterDbtRpcUnexpectedPollOutputError,
 )
